"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class ActiveWorkflows {
    constructor() {
        this.workflowData = {};
    }
    isActive(id) {
        return this.workflowData.hasOwnProperty(id);
    }
    allActiveWorkflows() {
        return Object.keys(this.workflowData);
    }
    get(id) {
        return this.workflowData[id];
    }
    async add(id, workflow, additionalData, getTriggerFunctions) {
        console.log('ADD ID (active): ' + id);
        this.workflowData[id] = {
            workflow
        };
        const triggerNodes = workflow.getTriggerNodes();
        let triggerResponse;
        for (const triggerNode of triggerNodes) {
            triggerResponse = await workflow.runTrigger(triggerNode, getTriggerFunctions, additionalData, 'trigger');
            if (triggerResponse !== undefined) {
                this.workflowData[id].triggerResponse = triggerResponse;
            }
        }
    }
    async remove(id) {
        console.log('REMOVE ID (active): ' + id);
        if (!this.isActive(id)) {
            throw new Error(`The workflow with the id "${id}" is currently not active and can so not be removed`);
        }
        const workflowData = this.workflowData[id];
        if (workflowData.triggerResponse && workflowData.triggerResponse.closeFunction) {
            await workflowData.triggerResponse.closeFunction();
        }
        delete this.workflowData[id];
    }
}
exports.ActiveWorkflows = ActiveWorkflows;
//# sourceMappingURL=ActiveWorkflows.js.map